Learn R Programming

ruv (version 0.9.7.2)

RUVI: RUV-I

Description

The RUV-I algorithm. Generally used as a preprocessing step to RUV-2, RUV-4, RUV-inv, RUV-rinv, or RUVIII. RUV1 is an alias of (identical to) RUVI.

Usage

RUVI(Y, eta, ctl, include.intercept = TRUE)

RUV1(Y, eta, ctl, include.intercept = TRUE)

Value

An adjusted data matrix (i.e., an adjusted Y)

Arguments

Y

The data. A m by n matrix, where m is the number of samples and n is the number of features.

eta

Gene-wise (as opposed to sample-wise) covariates. A matrix with n columns.

ctl

The negative controls. A logical vector of length n.

include.intercept

Add an intercept term to eta if it does not include one already.

Author

Johann Gagnon-Bartsch johanngb@umich.edu

Details

Implements the RUV-I algorithm as described in Gagnon-Bartsch, Jacob, and Speed (2013). Most often this algorithm is not used directly, but rather is called from RUV-2, RUV-4, RUV-inv, or RUV-rinv. Note that RUV1 and RUVI are two different names for the same (identical) function.

References

Using control genes to correct for unwanted variation in microarray data. Gagnon-Bartsch and Speed, 2012. Available at: https://academic.oup.com/biostatistics/article/13/3/539/248166.

Removing Unwanted Variation from High Dimensional Data with Negative Controls. Gagnon-Bartsch, Jacob, and Speed, 2013. Available at: https://statistics.berkeley.edu/tech-reports/820.

See Also

RUV2, RUV4, RUVinv, RUVrinv, RUVIII