Estimate the features' variances using the inverse method. This function is usually called from RUVinv and not normally intended for stand-alone use.
invvar(Y, ctl, XZ = NULL, eta = NULL, lambda = NULL,
invsvd = NULL)A list containing
Estimates of the features' variances. A vector of length n.
The "effective degrees of freedom"
Can be used to speed up future calls of invvar.
The data. A m by n matrix, where m is the number of samples and n is the number of features.
The negative controls. A logical vector of length n.
A m by (p + q) matrix containing both the factor(s) of interest (X) and known covariates (Z).
Gene-wise (as opposed to sample-wise) covariates. These covariates are adjusted for by RUV-1 before any further analysis proceeds. A matrix with n columns.
Ridge parameter. If specified, the ridged inverse method will be used.
Can be included to speed up execution. Generally used when calling invvar many times with different values of lambda.
Johann Gagnon-Bartsch johanngb@umich.edu
Removing Unwanted Variation from High Dimensional Data with Negative Controls. Gagnon-Bartsch, Jacob, and Speed, 2013. Available at: http://statistics.berkeley.edu/tech-reports/820.
RUVinv, RUVrinv