| ruv_shiny | R Documentation |
A Shiny App that allows quick exploration of a dataset using RUV methods.
ruv_shiny(Y, rowinfo, colinfo, options = list(port = 3840))
Y |
The data matrix. Rows are observations and columns are features (e.g. genes). |
rowinfo |
A dataframe of information about the observations. Should have the same number of rows as Y. Should contain at least one column that can be used as either a factor of interest or to define replicates. |
colinfo |
A dataframe of information about the observations. Should have the same number of rows as Y. Should contain at least one column that is a logical vector that can be used to define negative controls. |
options |
A list of options to pass to the shinyApp function. |
None. Calls shinyApp.
Johann Gagnon-Bartsch
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.