Learn R Programming

ruv (version 0.9.7.1)

inputcheck1: Input Check One

Description

Performs a basic sanity check on the arguments passed to RUV-2, RUV-4, RUV-inv, and RUV-rinv.

Usage

inputcheck1(Y, X, Z, ctl, check.na=TRUE)

Value

Returns NULL. The function is only called to check for problems in the arguments and to issue warnings if any problems are found.

Arguments

Y

The data. A m by n matrix, where m is the number of samples and n is the number of features.

X

The factor(s) of interest. A m by p matrix, where m is the number of samples and p is the number of factors of interest. Very often p = 1.

Z

Any additional covariates to include in the model. Either a m by q matrix of covariates, or simply 1 (the default) for an intercept term.

ctl

The negative controls. A logical vector of length n.

check.na

Whether to check for missing values.

See Also

RUV2, RUV4, RUVinv, RUVrinv